@@ -3,13 +3,14 @@
 #' @description
 #' Generates plots for [mlr3::TaskRegr], depending on argument `type`:
 #'   * `"target"`: Box plot of target variable (default).
-#'   * `"pairs"`: Passes data and additional arguments down to [GGally::ggpairs()].
-#'     Color is set to target column.
+#'   * `"pairs"`: Passes data and additional arguments down to
+#'   [GGally::ggpairs()]. Color is set to target column.
 #'
 #' @param object ([mlr3::TaskRegr]).
 #' @template param_type
 #' @param ... (`any`):
-#'   Additional argument, passed down to the underlying `geom` or plot functions.
+#'   Additional argument, passed down to the underlying `geom` or plot
+#'   functions.
 #'
 #' @return [ggplot2::ggplot()] object.
 #' @export
@@ -17,19 +18,23 @@
 #' library(mlr3)
 #' library(mlr3viz)
 #'
-#' task = mlr_tasks$get("mtcars")
+#' task = tsk("mtcars")
 #' task$select(c("am", "carb"))
 #'
 #' head(fortify(task))
 #' autoplot(task)
 #' autoplot(task, type = "pairs")
-autoplot.TaskRegr = function(object, type = "target", ...) {
+autoplot.TaskRegr = function(object, type = "target", ...) { # nolint
   assert_string(type)
 
   switch(type,
     "target" = {
       target = object$target_names
-      ggplot(data = object, aes_string(x = as.factor(target), y = target, fill = target)) + geom_boxplot(...) + xlab("")
+      ggplot(data = object, aes_string(
+        x = as.factor(target), y = target,
+        fill = target)) +
+        geom_boxplot(...) +
+        xlab("")
     },
 
     "pairs" = {
